const fs = require('fs');
const { colors, typography, spacing, shadows, radii, transition } = require('../index');
const { namespace } = require('./config');

const variables = Object.assign(
  {},
  colors.colors,
  typography.typeface,
  typography.fontSizes,
  typography.weights,
  typography.letterSpacings,
  spacing.scale,
  shadows.outer,
  shadows.inner,
  shadows.innerN,
  radii.values,
  transition.durations
);

const generate = {
  css() {
    return `:root {${Object.keys(variables).reduce(
      (css, name) => `${css}\n  ${`--${namespace}${name}`}: ${variables[name]};`,
      ''
    )}\n}\n`;
  },
  scss() {
    return Object.keys(variables).reduce(
      (css, name) => `${css}${`$${namespace}${name}`}: ${variables[name]};\n`,
      `$${namespace}namespace: '${namespace}';\n`
    );
  },
};

function generateTokensFile(type) {
  return generate[type]();
}

fs.writeFileSync('./index.css', generateTokensFile('css'));
fs.writeFileSync('./index.scss', generateTokensFile('scss'));
